@@ -1120,12 +1120,12 @@ get_text_with_style (GtkSourcePrintJob *job,
 	gboolean have_toggle;
 	
 	/* make sure the region to print is highlighted */
-// FIXME: still needed with gsv2?
 //	_gtk_source_buffer_highlight_region (job->priv->buffer, start, end, TRUE);
+	gtk_source_buffer_ensure_highlight (job->priv->buffer, start, end);
 
 	next_toggle = *start;
 	have_toggle = gtk_text_iter_forward_to_tag_toggle (&next_toggle, NULL);
-	
+
 	/* FIXME: handle invisible text properly.  This also assumes
 	 * the text has no embedded images and stuff */
 	while (gtk_text_iter_compare (start, end) < 0)
@@ -2055,9 +2055,9 @@ gtk_source_print_job_setup_from_view (GtkSourcePrintJob *job,
 	if (job->priv->buffer == NULL && buffer != NULL)
 		gtk_source_print_job_set_buffer (job, buffer);
 
-	gtk_source_print_job_set_tabs_width (job, gtk_source_view_get_tabs_width (view));
+	gtk_source_print_job_set_tabs_width (job, gtk_source_view_get_tab_width (view));
 	if (buffer != NULL)
-		gtk_source_print_job_set_highlight (job, gtk_source_buffer_get_highlight (buffer));
+		gtk_source_print_job_set_highlight (job, gtk_source_buffer_get_highlight_syntax (buffer));
 	gtk_source_print_job_set_wrap_mode (job, gtk_text_view_get_wrap_mode (GTK_TEXT_VIEW (view)));
 
 	pango_context = gtk_widget_get_pango_context (GTK_WIDGET (view));
